..
   Copyright (C) 2014 Jaakko Luttinen

   This file is licensed under Version 3.0 of the GNU General Public
   License. See LICENSE for a text of the license.

   This file is part of BayesPy.

   BayesPy is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License version 3 as
   published by the Free Software Foundation.

   BayesPy is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with BayesPy.  If not, see <http://www.gnu.org/licenses/>.


Distributions
=============

.. currentmodule:: bayespy.inference.vmp.nodes

.. autosummary::
   :toctree: generated/

   stochastic.Distribution
   expfamily.ExponentialFamilyDistribution
   gaussian.GaussianDistribution
   gaussian.GaussianARDDistribution
   gaussian.GaussianGammaISODistribution
   gaussian.GaussianGammaARDDistribution
   gaussian.GaussianWishartDistribution
   gaussian_markov_chain.GaussianMarkovChainDistribution
   gaussian_markov_chain.SwitchingGaussianMarkovChainDistribution
   gaussian_markov_chain.VaryingGaussianMarkovChainDistribution
   gamma.GammaDistribution
   wishart.WishartDistribution
   beta.BetaDistribution
   dirichlet.DirichletDistribution
   bernoulli.BernoulliDistribution
   binomial.BinomialDistribution
   categorical.CategoricalDistribution
   categorical_markov_chain.CategoricalMarkovChainDistribution
   multinomial.MultinomialDistribution
   poisson.PoissonDistribution
